@@ -1,6 +1,6 @@
 #!/usr/bin/env python
-import pathlib
 
+import pathlib
 import paramiko
 import requests
 import sys
@@ -33,11 +33,7 @@ class MasterSSH:
         if args.verbose:
             logger.setLevel(logging.DEBUG)
 
-        # Load configuration
-        self.parse_config(args)
-
-        # Set log's path:
-        self.init_logs()
+        self.config = args
 
         cred_source_type = None
         cred_source_path = None
@@ -139,14 +135,14 @@ class MasterSSH:
             # If there are specific servers user wants to use, use them ...
             if use_selected_servers:
                 if cred['name'] in self.selected_servers:
-                    thread_pool[thread_pos] = threading.Thread(target=self.connect, name=cred['name'], args=(cred['name'], cred['host'], cred['username'], cred['password'], self.config.getint('connection', 'port')))
+                    thread_pool[thread_pos] = threading.Thread(target=self.connect, name=cred['name'], args=(cred['name'], cred['host'], cred['username'], cred['password'], self.config.port))
                     thread_pool[thread_pos].daemon = True
                     thread_pool[thread_pos].start()
                     thread_pos += 1
 
             # ... if not, use all of them
             else:
-                thread_pool[thread_pos] = threading.Thread(target=self.connect, name=cred['name'], args=(cred['name'], cred['host'], cred['username'], cred['password'], self.config.getint('connection', 'port')))
+                thread_pool[thread_pos] = threading.Thread(target=self.connect, name=cred['name'], args=(cred['name'], cred['host'], cred['username'], cred['password'], self.config.port))
                 thread_pool[thread_pos].daemon = True
                 thread_pool[thread_pos].start()
                 thread_pos += 1
@@ -162,8 +158,7 @@ class MasterSSH:
 
     def connect(self, name, host, username, password, port):
         tries = 1
-        max_tries = self.config.getint('connection', 'max_retries')
-        delay = self.config.getfloat('connection', 'delay')
+        max_tries = self.config.max_retries
 
         while True:
             if tries == max_tries:
@@ -188,9 +183,8 @@ class MasterSSH:
                 self.print_error("Failed to connect! Retrying (%s/%s)" % (tries, max_tries))
                 self.print_exception(e)
 
-                connected = False
                 tries += 1
-                time.sleep(delay)
+                time.sleep(self.config.retry_delay)
 
     """
     Create connection closing threads
@@ -219,7 +213,7 @@ class MasterSSH:
         try:
             if self.connection_pool[name].get_transport():
                 if self.connection_pool[name].get_transport().is_active():
-                    self.connection_pool[name].exec_command('exit', timeout=self.config.getint('timeout', 'exit_cmd'))
+                    self.connection_pool[name].exec_command('exit', timeout=self.config.exit_timeout)
         except Exception as e:
             self.print_exception(e)
 
@@ -309,7 +303,7 @@ class MasterSSH:
 
                                 try:
                                     if connection.get_transport().is_active():
-                                        connection.exec_command('exit', timeout=int(self.config.get('timeout', 'exit_cmd')))
+                                        connection.exec_command('exit', timeout=self.config.exit_timeout)
                                         connection.close()
 
                                         self.connection_pool.pop(server)
@@ -479,19 +473,4 @@ class MasterSSH:
         logger.error(colored(message, on_color='on_red', attrs=['bold']))
 
     def print_exception(self, err):
-        logger.exception(err)
-
-    def parse_config(self, args):
-        self.config = configparser.ConfigParser()
-        self.config.read("/%s/config.ini" % pathlib.Path(__file__).parent.absolute())
-
-        if args.port:
-            self.config.set('connection', 'port', args.port)
-
-    def init_logs(self):
-        log_file = self.config.get('log', 'ssh_client')
-
-        if not os.path.isfile(log_file):
-            open(log_file, 'w').close()
-
-        paramiko.util.log_to_file(log_file)
+        logger.exception(err)
\ No newline at end of file
